@@ -1,5 +1,6 @@
 use {
-    clap::{value_t, value_t_or_exit, App, Arg},
+    clap::{crate_name, value_t, value_t_or_exit, App, Arg},
+    log::*,
     solana_clap_utils::{
         input_parsers::{pubkey_of, pubkeys_of, value_of},
         input_validators::{
@@ -154,13 +155,14 @@ fn main() {
         .arg(
             Arg::with_name("bpf_program")
                 .long("bpf-program")
-                .value_name("ADDRESS BPF_PROGRAM.SO")
+                .value_name("ADDRESS_OR_PATH BPF_PROGRAM.SO")
                 .takes_value(true)
                 .number_of_values(2)
                 .multiple(true)
                 .help(
                     "Add a BPF program to the genesis configuration. \
-                       If the ledger already exists then this parameter is silently ignored",
+                       If the ledger already exists then this parameter is silently ignored. \
+                       First argument can be a public key or path to file that can be parsed as a keypair",
                 ),
         )
         .arg(
@@ -339,6 +341,8 @@ fn main() {
     };
     let _logger_thread = redirect_stderr_to_file(logfile);
 
+    info!("{} {}", crate_name!(), solana_version::version!());
+    info!("Starting validator with: {:#?}", std::env::args_os());
     solana_core::validator::report_target_features();
 
     // TODO: Ideally test-validator should *only* allow private addresses.
@@ -400,10 +404,13 @@ fn main() {
         for address_program in values.chunks(2) {
             match address_program {
                 [address, program] => {
-                    let address = address.parse::<Pubkey>().unwrap_or_else(|err| {
-                        println!("Error: invalid address {}: {}", address, err);
-                        exit(1);
-                    });
+                    let address = address
+                        .parse::<Pubkey>()
+                        .or_else(|_| read_keypair_file(address).map(|keypair| keypair.pubkey()))
+                        .unwrap_or_else(|err| {
+                            println!("Error: invalid address {}: {}", address, err);
+                            exit(1);
+                        });
 
                     let program_path = PathBuf::from(program);
                     if !program_path.exists() {
